# tapyr

This is a python library that implement binding for [TAPIRh](ttps://github.com/tap-ir/tapir) REST api.

## Installation

```
git clone https://github.com/tap-ir/tapyr.git
cd tapyr
pip install .
```
